"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ASTGenerator_1 = require("./ASTGenerator");
describe("ASTGenerator", () => {
    test.each `
    given                                | expected
    ${["(", "list", "a", "b", "c", ")"]} | ${["(", "list", "a", "b", "c", ")"]}
    ${["(", "cons", "b", "c", ")", ")"]} | ${["(", "cons", "b", "c", ")"]}
  `("untilClosingBracket($given) ~= $expected", ({ given, expected }) => {
        expect(ASTGenerator_1.untilClosingBracket(given)).toEqual(expected);
    });
    describe("withoutEnclosingBrackets", () => {
        describe("when giving enclosing brackets", () => {
            it("return the inner part", () => {
                expect(ASTGenerator_1.withoutEnclosingBrackets(["(", "a", ")"])).toEqual(["a"]);
            });
        });
        describe("when starting with smth else", () => {
            it("doesnt do anything", () => {
                expect(ASTGenerator_1.withoutEnclosingBrackets(["b", "a", ")"])).toEqual(["b", "a", ")"]);
            });
        });
        describe("when ending with smth else", () => {
            it("doesnt do anything", () => {
                expect(ASTGenerator_1.withoutEnclosingBrackets(["(", "a", "c"])).toEqual(["(", "a", "c"]);
            });
        });
    });
    test.each `
    given                                                       | expected
    ${["(", "list", "a", "b", "c", ")"]}                        | ${[["list", "a", "b", "c"]]}
    ${["(", "cons", "a", "(", "cons", "b", "c", ")", ")"]}      | ${[["cons", "a", ["cons", "b", "c"]]]}
    ${["(", "cons", "a", "b", ")", "(", "cons", "a", "b", ")"]} | ${[["cons", "a", "b"], ["cons", "a", "b"]]}
  `("generateAST($given) ~= $expected", ({ given, expected }) => {
        expect(ASTGenerator_1.generateASTs(given)).toEqual(expected);
    });
});
